@@ -7,6 +7,7 @@ from .config import AgentConfig
 from .agent import LocalAgent, RemoteAgent, resolve_agent
 from .vector import VectorStore
 from .keyvalue import KeyValueStore
+from .objectstore import ObjectStore
 from .types import AgentContextInterface
 from .util import deprecated
 
@@ -60,6 +61,10 @@ class AgentContext(AgentContextInterface):
         """
         self.vector: VectorStore = services.get("vector")
         """
+        the object store
+        """
+        self.objectstore: ObjectStore = services.get("objectstore")
+        """
         the version of the Agentuity SDK
         """
         self.sdkVersion = os.getenv("AGENTUITY_SDK_VERSION", "unknown")
